from referencing._core import (  # noqa: F401
    OPAQUE_SPECIFICATION,
    IdentifiedResource,
    Registry,
)
